package com.jiuqi.office.excel;

import com.jiuqi.grid.GridData;
import com.jiuqi.util.StringUtils;
import com.jiuqi.util.zip.ZipEntry;
import com.jiuqi.util.zip.ZipOutputStream;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;

/* loaded from: com_jiuqi_office_excel.jar:com/jiuqi/office/excel/BatchExportor.class */
public class BatchExportor {
    private boolean autoAdjust;
    private boolean addTitle;
    private boolean toSingleFile;
    private GridIterator iterator;
    private boolean doNotCheckNumberIsNull;
    private Set filenames = new HashSet();
    private HashMap cellStyleHashMap = new HashMap();
    private int transparentColor = -16777201;
    private Map HSSFFontMap = new HashMap();

    public BatchExportor(GridIterator iterator) {
        this.iterator = iterator;
    }

    public void setAutoAdjust(boolean autoAdjust) {
        this.autoAdjust = autoAdjust;
    }

    public void setAddTitle(boolean addTitle) {
        this.addTitle = addTitle;
    }

    public void setToSingleFile(boolean toSingleFile) {
        this.toSingleFile = toSingleFile;
    }

    public void setTransparentColor(int transparentColor) {
        this.transparentColor = transparentColor;
    }

    public boolean isDoNotCheckNumberIsNull() {
        return this.doNotCheckNumberIsNull;
    }

    public void setDoNotCheckNumberIsNull(boolean doNotCheckNumberIsNull) {
        this.doNotCheckNumberIsNull = doNotCheckNumberIsNull;
    }

    public boolean isAutoAdjust() {
        return this.autoAdjust;
    }

    public boolean isAddTitle() {
        return this.addTitle;
    }

    public boolean isToSingleFile() {
        return this.toSingleFile;
    }

    public void Export(OutputStream outStream) throws Exception {
        if (this.toSingleFile) {
            exportToSingle(outStream);
        } else {
            exportToBatch(outStream);
        }
    }

    private void exportToSingle(OutputStream outStream) throws ExcelException {
        this.filenames.clear();
        HSSFWorkbook wb = new HSSFWorkbook();
        while (this.iterator.next()) {
            GridData reportData = this.iterator.getGridData();
            String rptTitle = validateFileName(this.iterator.getTitle());
            HSSFSheet sheet = wb.createSheet(rptTitle);
            WorksheetWriter sheetWriter = new WorksheetWriter(wb, sheet, reportData, this.cellStyleHashMap);
            sheetWriter.setHSSFFontMap(this.HSSFFontMap);
            sheetWriter.setAddTitle(this.addTitle);
            if (this.addTitle) {
                sheetWriter.setTitle(this.iterator.getTitle());
            } else {
                sheetWriter.setTitle("");
            }
            sheetWriter.setAutoAdjust(this.autoAdjust);
            sheetWriter.setDoNotCheckNumberIsNull(this.doNotCheckNumberIsNull);
            sheetWriter.setTransparentColor(this.transparentColor);
            sheetWriter.writeWorkSheet();
        }
        try {
            wb.write(outStream);
        } catch (IOException e) {
            throw new ExcelException(e);
        }
    }

    private void exportToBatch(OutputStream outStream) throws ExcelException {
        this.filenames.clear();
        ZipOutputStream zipOutStream = new ZipOutputStream(outStream);
        byte[] buf = new byte[1024];
        while (this.iterator.next()) {
            SimpleExportor excelExportor = new SimpleExportor(this.iterator.getTitle(), this.iterator.getGridData());
            excelExportor.setHSSFFontMap((HashMap) this.HSSFFontMap);
            excelExportor.setAddTitle(this.addTitle);
            excelExportor.setAutoAdjust(this.autoAdjust);
            excelExportor.setDoNotCheckNumberIsNull(this.doNotCheckNumberIsNull);
            ByteArrayOutputStream outBuffer = new ByteArrayOutputStream();
            excelExportor.export(outBuffer);
            ZipEntry zipEntry = new ZipEntry(String.valueOf(validateFileName(this.iterator.getTitle())) + ".xls");
            zipEntry.setSize(outBuffer.size());
            Date now = new Date();
            zipEntry.setTime(now.getTime());
            try {
                zipOutStream.putNextEntry(zipEntry);
                InputStream is = new ByteArrayInputStream(outBuffer.toByteArray());
                while (true) {
                    int readLen = is.read(buf, 0, 1024);
                    if (readLen == -1) {
                        break;
                    } else {
                        zipOutStream.write(buf, 0, readLen);
                    }
                }
            } catch (IOException e) {
                throw new ExcelException(e);
            }
        }
        try {
            zipOutStream.close();
        } catch (IOException e2) {
            throw new ExcelException(e2);
        }
    }

    private String validateFileName(String filename) {
        if (StringUtils.isEmpty(filename) || filename.length() >= 32) {
            filename = ExportConsts.DEFAULT_RPTNAME;
        }
        String newName = filename;
        int index = 0;
        while (this.filenames.contains(newName)) {
            index++;
            newName = String.valueOf(filename) + ExportConsts.TITLE_SEPARATOR + Integer.toString(index);
        }
        this.filenames.add(newName);
        return newName;
    }
}
